public inbox for gcc-cvs@sourceware.org
help / color / mirror / Atom feed
* [gcc r12-7435] lto-plugin: update comments - remove hardwired gold
@ 2022-03-01 15:42 Martin Liska
  0 siblings, 0 replies; only message in thread
From: Martin Liska @ 2022-03-01 15:42 UTC (permalink / raw)
  To: gcc-cvs

https://gcc.gnu.org/g:4fe0e1a45e5583bddedc8edfbaa0f090a145019e

commit r12-7435-g4fe0e1a45e5583bddedc8edfbaa0f090a145019e
Author: Martin Liska <mliska@suse.cz>
Date:   Tue Mar 1 16:40:45 2022 +0100

    lto-plugin: update comments - remove hardwired gold
    
    lto-plugin/ChangeLog:
    
            * lto-plugin.c (process_offload_section): Use a linker as many
            comments are connected to gold linker.
            (process_option): Likewise.

Diff:
---
 lto-plugin/lto-plugin.c | 14 +++++++-------
 1 file changed, 7 insertions(+), 7 deletions(-)

diff --git a/lto-plugin/lto-plugin.c b/lto-plugin/lto-plugin.c
index c9c048d3631..593fbc91383 100644
--- a/lto-plugin/lto-plugin.c
+++ b/lto-plugin/lto-plugin.c
@@ -1,4 +1,4 @@
-/* LTO plugin for gold and/or GNU ld.
+/* LTO plugin for linkers like gold, GNU ld or mold.
    Copyright (C) 2009-2022 Free Software Foundation, Inc.
    Contributed by Rafael Avila de Espindola (espindola@google.com).
 
@@ -16,11 +16,11 @@ You should have received a copy of the GNU General Public License
 along with this program; see the file COPYING3.  If not see
 <http://www.gnu.org/licenses/>.  */
 
-/* The plugin has only one external function: onload. Gold passes it an array of
-   function that the plugin uses to communicate back to gold.
+/* The plugin has only one external function: onload. A linker passes it an array of
+   function that the plugin uses to communicate back to the linker.
 
-   With the functions provided by gold, the plugin can be notified when
-   gold first analyzes a file and pass a symbol table back to gold. The plugin
+   With the functions provided by the linker, the plugin can be notified when
+   the linker first analyzes a file and pass a symbol table back to the linker. The plugin
    is also notified when all symbols have been read and it is time to generate
    machine code for the necessary symbols.
 
@@ -1139,7 +1139,7 @@ process_offload_section (void *data, const char *name, off_t offset, off_t len)
   return 1;
 }
 
 /* Callback used by gold to check if the plugin will claim FILE. Writes
    the result in CLAIMED. */
 
 static enum ld_plugin_status
@@ -1374,7 +1374,7 @@ process_option (const char *option)
   verbose = verbose || debug;
 }
 
 /* Called by gold after loading the plugin. TV is the transfer vector. */
 
 enum ld_plugin_status
 onload (struct ld_plugin_tv *tv)


^ permalink raw reply	[flat|nested] only message in thread

only message in thread, other threads:[~2022-03-01 15:42 UTC | newest]

Thread overview: (only message) (download: mbox.gz / follow: Atom feed)
-- links below jump to the message on this page --
@@ -1139,7 +1139,7 @@ process_offload_section (void *data, const char *name, off_t offset, off_t len)
 }
 
-/* Callback used by gold to check if the plugin will claim FILE. Writes
+/* Callback used by a linker to check if the plugin will claim FILE. Writes
    the result in CLAIMED. */
 
@@ -1374,7 +1374,7 @@ process_option (const char *option)
 }
 
-/* Called by gold after loading the plugin. TV is the transfer vector. */
+/* Called by a linker after loading the plugin. TV is the transfer vector. */
 
 enum ld_plugin_status
2022-03-01 15:42 [gcc r12-7435] lto-plugin: update comments - remove hardwired gold Martin Liska

This is a public inbox, see mirroring instructions
for how to clone and mirror all data and code used for this inbox;
as well as URLs for read-only IMAP folder(s) and NNTP newsgroup(s).